indexing

   description: "Class that covers current process related routines."
   usage: "Just inherit from this class."

   author: "Berend de Boer"
   date: "$Date: Sat, 14 Oct 2000 08:59:36 +0200 $"
   revision: "$Revision: 1.9 $"

class 

   STDC_CURRENT_PROCESS


inherit
   
   STDC_PROCESS

   CAPI_STDLIB

   CAPI_LOCALE

   CAPI_TIME
   

feature -- my stdandard input/output/error

   stdin: STDC_TEXT_FILE is
      once
         create Result.attach_to_stream (stream_stdin, "r")
      end

   stdout: STDC_TEXT_FILE is
      once
         create Result.attach_to_stream (stream_stdout, "w")
      end
         
   stderr: STDC_TEXT_FILE is
      once
         create Result.attach_to_stream (stream_stderr, "w")
      end


feature {NONE}

   abort is
         -- Causes abnormal process termination
         -- On many systems, dumps core
      do
         posix_abort
      end
   
   clock: INTEGER is
         -- return approximation of processor time used by the
         -- program, or -1 if unknown      
      do
         Result := posix_clock
      end
   
   exit (a_status: INTEGER) is
         -- terminate this process with exit code `a_status'
      do
         posix_exit (a_status)
      end


feature -- global locale
   
   locale: STRING is
         -- return current locale
      do
         Result := sh.pointer_to_string (posix_setlocale (LC_ALL, default_pointer))
      end

   numeric_format: STDC_LOCALE_NUMERIC is
         -- various information for formatting numbers and monetary
         -- quantities
      once
         create Result
      end
   
   set_locale (category: INTEGER; new_locale: STRING) is
         -- set given locale to `new_locale'
      local
         p: POINTER
      do
         p := posix_setlocale (category, sh.string_to_pointer (new_locale))
         if p = default_pointer then
            raise_posix_error
         end
      end
   
   set_c_locale is
         -- set locale to the Standard C locale (the default)
      do
         set_locale (LC_ALL, "C")
      end

   set_native_decimal_point is
         -- set the decimal point character
      do
         set_locale (LC_NUMERIC, "")
      end
   
   set_native_locale is
         -- set entire locale to the native's setting
      do
         set_locale (LC_ALL, "")
      end

   set_native_time is
         -- set time display to the native's setting
      do
         set_locale (LC_TIME, "")
      end
   

end -- class STDC_CURRENT_PROCESS
